# demonstrating basics of using simple graphics

from random import randrange
from time import sleep

from simple_graphics import SimpleGraphics


def basic_demo():
    """
    Demonstrates almost all the (rather limited!) features of SquareGraphics
    in a very basic way: straight-line code.
    The only two features not demonstrated here are clearing and closing.
    """
    sg = SimpleGraphics()
    sg.set_status('Welcome!')
    w = sg.width
    h = sg.height
    print(f'window height = {h} rows')
    print(f'window width = {w} columns')
    print(f'number of painted squares: {sg.count_squares()}\n')

    print('painting upper-left corner')
    sg.paint(0, 0)
    print(f'painted? {sg.is_painted(0, 0)}')
    print(f'number of painted squares: {sg.count_squares()}\n')

    print('painting upper-right corner')
    sg.paint(w - 1, 0)

    print('painting lower-right corner')
    sg.paint(w - 1, h - 1)

    print('painting lower-left corner')
    sg.paint(0, h - 1)

    print(f'number of painted squares: {sg.count_squares()}')

    print('unpainting upper-left corner')
    sg.unpaint(0, 0)
    print(f'painted? {sg.is_painted(0, 0)}')
    print(f'number of painted squares: {sg.count_squares()}\n')

    return sg


def clear_close_demo():
    sg = basic_demo()
    sleep(2)
    sg.clear()
    sleep(1)
    sg.close()


def border_demo():
    sg = SimpleGraphics()
    for x in range(sg.width):
        sg.paint(x, 0)
        sg.paint(x, sg.height - 1)
    for y in range(1, sg.height - 1):
        sg.paint(0, y)
        sg.paint(sg.width - 1, y)
    return sg


def scatter_demo():
    sg = SimpleGraphics()
    for x in range(sg.width):
        y = randrange(sg.height)
        sg.paint(x, y)
    return sg


def blinker_demo():
    sg = SimpleGraphics()
    # fill about half the board
    for y in range(sg.height):
        for x in range(sg.width):
            if randrange(2) == 1:
                sg.paint(x, y)
    # toggle a bunch of random cells
    for _ in range(sg.width * sg.height):
        x = randrange(sg.width)
        y = randrange(sg.height)
        if sg.is_painted(x, y):
            sg.unpaint(x, y)
        else:
            sg.paint(x, y)
    sg.close()


def twinkle_demo():
    sg = SimpleGraphics()
    x = randrange(sg.width)
    y = randrange(sg.height)
    for _ in range(100):
        if sg.is_painted(x, y):
            sg.unpaint(x, y)
        else:
            sg.paint(x, y)
        sleep(0.25)
    sg.close()


def animate_demo():
    sg = SimpleGraphics()
    x = 0
    y = sg.height // 2
    sg.paint(x, y)
    for x in range(1, sg.width):
        sg.unpaint(x - 1, y)
        sg.paint(x, y)
        sleep(0.1)
    sleep(2)
    sg.close()


def toggle_repl():
    sg = SimpleGraphics()
    for _ in range(5):
        x = int(input('col'))   # does not error check
        y = int(input('row'))
        if sg.is_painted(x, y):
            sg.unpaint(x, y)
        else:
            sg.paint(x, y)
        sg.set_status(f'squares: {sg.count_squares()}')
    sg.close()
